Learn R Programming

BRDT (version 0.1.0)

bcost_RDT: Binomial RDT Cost

Description

Define the cost function of RDT, mainly determined by the test sample size (for binomial RDT)

Usage

bcost_RDT(Cf, Cv, n)

Arguments

Cf

Fixed costs

Cv

Variable costs.

n

Optimal test sample size

Value

Binomial RDT cost

See Also

bcost_RG, bcost_WS, bcost_expected

Examples

Run this code
# NOT RUN {
#the n value can be the minimum test sample size obtained from \code{\link{boptimal_n}}.
n_optimal <- 20
bcost_RDT(Cf = 0, Cv = 10, n = n_optimal);
# }

Run the code above in your browser using DataLab