boptimal_n: Optimal Test Sample Size for Binomial RDT
Description
Define the optimal function to find the optimal test plan with minimum test sample size given an acceptable
level of consumer's risk (for binomial RDT).
Usage
boptimal_n(c, pi, R, thres_CR)
Arguments
c
Maximum allowable failures
pi
Failure probability
R
Lower level reliability requirement
thres_CR
Threshold (acceptable level) of consumer's risk
Value
Minimum test sample size
See Also
boptimal_cost for getting the optial test plan with minimum overall cost;
bdata_generator for generating optimal test plans dataset;