powered by
Define the cost function of RDT, mainly determined by the test sample size (for binomial RDT)
bcost_RDT(Cf, Cv, n)
Fixed costs
Variable costs.
Optimal test sample size
Binomial RDT cost
bcost_RG, bcost_WS, bcost_expected
bcost_RG
bcost_WS
bcost_expected
# NOT RUN { #the n value can be the minimum test sample size obtained from \code{\link{boptimal_n}}. n_optimal <- 20 bcost_RDT(Cf = 0, Cv = 10, n = n_optimal); # }
Run the code above in your browser using DataLab